@@ -14,17 +14,17 @@ class TestBuildConfig:
         assert metadata.build_config == metadata.build_config == {}
 
     def test_not_table(self, isolation):
-        config = {'build': 0}
+        config = {"build": 0}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        with pytest.raises(TypeError, match='Field `tool.hatch.build` must be a table'):
+        with pytest.raises(TypeError, match="Field `tool.hatch.build` must be a table"):
             _ = metadata.build_config
 
     def test_correct(self, isolation):
-        config = {'build': {'reproducible': True}}
+        config = {"build": {"reproducible": True}}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        assert metadata.build_config == metadata.build_config == {'reproducible': True}
+        assert metadata.build_config == metadata.build_config == {"reproducible": True}
 
 
 class TestBuildTargets:
@@ -35,70 +35,70 @@ class TestBuildTargets:
         assert metadata.build_targets == metadata.build_targets == {}
 
     def test_not_table(self, isolation):
-        config = {'build': {'targets': 0}}
+        config = {"build": {"targets": 0}}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        with pytest.raises(TypeError, match='Field `tool.hatch.build.targets` must be a table'):
+        with pytest.raises(TypeError, match="Field `tool.hatch.build.targets` must be a table"):
             _ = metadata.build_targets
 
     def test_correct(self, isolation):
-        config = {'build': {'targets': {'wheel': {'versions': ['standard']}}}}
+        config = {"build": {"targets": {"wheel": {"versions": ["standard"]}}}}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        assert metadata.build_targets == metadata.build_targets == {'wheel': {'versions': ['standard']}}
+        assert metadata.build_targets == metadata.build_targets == {"wheel": {"versions": ["standard"]}}
 
 
 class TestVersionSourceName:
     def test_empty(self, isolation):
         with pytest.raises(
-            ValueError, match='The `source` option under the `tool.hatch.version` table must not be empty if defined'
+            ValueError, match="The `source` option under the `tool.hatch.version` table must not be empty if defined"
         ):
-            _ = HatchMetadata(isolation, {'version': {'source': ''}}, None).version.source_name
+            _ = HatchMetadata(isolation, {"version": {"source": ""}}, None).version.source_name
 
     def test_not_table(self, isolation):
-        with pytest.raises(TypeError, match='Field `tool.hatch.version.source` must be a string'):
-            _ = HatchMetadata(isolation, {'version': {'source': 9000}}, None).version.source_name
+        with pytest.raises(TypeError, match="Field `tool.hatch.version.source` must be a string"):
+            _ = HatchMetadata(isolation, {"version": {"source": 9000}}, None).version.source_name
 
     def test_correct(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {'source': 'foo'}}, None)
+        metadata = HatchMetadata(isolation, {"version": {"source": "foo"}}, None)
 
-        assert metadata.version.source_name == metadata.version.source_name == 'foo'
+        assert metadata.version.source_name == metadata.version.source_name == "foo"
 
     def test_default(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {}}, None)
+        metadata = HatchMetadata(isolation, {"version": {}}, None)
 
-        assert metadata.version.source_name == metadata.version.source_name == 'regex'
+        assert metadata.version.source_name == metadata.version.source_name == "regex"
 
 
 class TestVersionSchemeName:
     def test_missing(self, isolation):
         with pytest.raises(
-            ValueError, match='The `scheme` option under the `tool.hatch.version` table must not be empty if defined'
+            ValueError, match="The `scheme` option under the `tool.hatch.version` table must not be empty if defined"
         ):
-            _ = HatchMetadata(isolation, {'version': {'scheme': ''}}, None).version.scheme_name
+            _ = HatchMetadata(isolation, {"version": {"scheme": ""}}, None).version.scheme_name
 
     def test_not_table(self, isolation):
-        with pytest.raises(TypeError, match='Field `tool.hatch.version.scheme` must be a string'):
-            _ = HatchMetadata(isolation, {'version': {'scheme': 9000}}, None).version.scheme_name
+        with pytest.raises(TypeError, match="Field `tool.hatch.version.scheme` must be a string"):
+            _ = HatchMetadata(isolation, {"version": {"scheme": 9000}}, None).version.scheme_name
 
     def test_correct(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {'scheme': 'foo'}}, None)
+        metadata = HatchMetadata(isolation, {"version": {"scheme": "foo"}}, None)
 
-        assert metadata.version.scheme_name == metadata.version.scheme_name == 'foo'
+        assert metadata.version.scheme_name == metadata.version.scheme_name == "foo"
 
     def test_default(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {}}, None)
+        metadata = HatchMetadata(isolation, {"version": {}}, None)
 
-        assert metadata.version.scheme_name == metadata.version.scheme_name == 'standard'
+        assert metadata.version.scheme_name == metadata.version.scheme_name == "standard"
 
 
 class TestVersionSource:
     def test_unknown(self, isolation):
-        with pytest.raises(ValueError, match='Unknown version source: foo'):
-            _ = HatchMetadata(isolation, {'version': {'source': 'foo'}}, PluginManager()).version.source
+        with pytest.raises(ValueError, match="Unknown version source: foo"):
+            _ = HatchMetadata(isolation, {"version": {"source": "foo"}}, PluginManager()).version.source
 
     def test_cached(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {}}, PluginManager())
+        metadata = HatchMetadata(isolation, {"version": {}}, PluginManager())
 
         assert metadata.version.source is metadata.version.source
         assert isinstance(metadata.version.source, RegexSource)
@@ -106,11 +106,11 @@ class TestVersionSource:
 
 class TestVersionScheme:
     def test_unknown(self, isolation):
-        with pytest.raises(ValueError, match='Unknown version scheme: foo'):
-            _ = HatchMetadata(isolation, {'version': {'scheme': 'foo'}}, PluginManager()).version.scheme
+        with pytest.raises(ValueError, match="Unknown version scheme: foo"):
+            _ = HatchMetadata(isolation, {"version": {"scheme": "foo"}}, PluginManager()).version.scheme
 
     def test_cached(self, isolation):
-        metadata = HatchMetadata(isolation, {'version': {}}, PluginManager())
+        metadata = HatchMetadata(isolation, {"version": {}}, PluginManager())
 
         assert metadata.version.scheme is metadata.version.scheme
         assert isinstance(metadata.version.scheme, StandardScheme)
@@ -124,17 +124,17 @@ class TestMetadata:
         assert metadata.metadata.config == metadata.metadata.config == {}
 
     def test_not_table(self, isolation):
-        config = {'metadata': 0}
+        config = {"metadata": 0}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        with pytest.raises(TypeError, match='Field `tool.hatch.metadata` must be a table'):
+        with pytest.raises(TypeError, match="Field `tool.hatch.metadata` must be a table"):
             _ = metadata.metadata.config
 
     def test_correct(self, isolation):
-        config = {'metadata': {'option': True}}
+        config = {"metadata": {"option": True}}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        assert metadata.metadata.config == metadata.metadata.config == {'option': True}
+        assert metadata.metadata.config == metadata.metadata.config == {"option": True}
 
 
 class TestMetadataAllowDirectReferences:
@@ -145,14 +145,35 @@ class TestMetadataAllowDirectReferences:
         assert metadata.metadata.allow_direct_references is metadata.metadata.allow_direct_references is False
 
     def test_not_boolean(self, isolation):
-        config = {'metadata': {'allow-direct-references': 9000}}
+        config = {"metadata": {"allow-direct-references": 9000}}
         metadata = HatchMetadata(str(isolation), config, None)
 
-        with pytest.raises(TypeError, match='Field `tool.hatch.metadata.allow-direct-references` must be a boolean'):
+        with pytest.raises(TypeError, match="Field `tool.hatch.metadata.allow-direct-references` must be a boolean"):
             _ = metadata.metadata.allow_direct_references
 
     def test_correct(self, isolation):
-        config = {'metadata': {'allow-direct-references': True}}
+        config = {"metadata": {"allow-direct-references": True}}
         metadata = HatchMetadata(str(isolation), config, None)
 
         assert metadata.metadata.allow_direct_references is True
+
+
+class TestMetadataAllowAmbiguousFeatures:
+    def test_default(self, isolation):
+        config = {}
+        metadata = HatchMetadata(str(isolation), config, None)
+
+        assert metadata.metadata.allow_ambiguous_features is metadata.metadata.allow_ambiguous_features is False
+
+    def test_not_boolean(self, isolation):
+        config = {"metadata": {"allow-ambiguous-features": 9000}}
+        metadata = HatchMetadata(str(isolation), config, None)
+
+        with pytest.raises(TypeError, match="Field `tool.hatch.metadata.allow-ambiguous-features` must be a boolean"):
+            _ = metadata.metadata.allow_ambiguous_features
+
+    def test_correct(self, isolation):
+        config = {"metadata": {"allow-ambiguous-features": True}}
+        metadata = HatchMetadata(str(isolation), config, None)
+
+        assert metadata.metadata.allow_ambiguous_features is True
