@@ -3,22 +3,23 @@ from hatch.utils.fs import Path
 from hatchling.__about__ import __version__
 from hatchling.metadata.spec import DEFAULT_METADATA_VERSION
 
-from ..new.default import get_files as get_template_files
+from ..new.feature_no_src_layout import get_files as get_template_files
 from .utils import update_record_file_contents
 
 
 def get_files(**kwargs):
-    metadata_directory = kwargs.get('metadata_directory', '')
+    metadata_directory = kwargs.get("metadata_directory", "")
 
-    files = []
-    for f in get_template_files(**kwargs):
-        if str(f.path) == 'LICENSE.txt':
-            files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
+    files = [
+        File(Path(metadata_directory, "licenses", f.path), f.contents)
+        for f in get_template_files(**kwargs)
+        if str(f.path) == "LICENSE.txt"
+    ]
 
-    files.append(File(Path('my_app.py'), ''))
-    files.append(
+    files.extend((
+        File(Path("my_app.py"), ""),
         File(
-            Path(metadata_directory, 'WHEEL'),
+            Path(metadata_directory, "WHEEL"),
             f"""\
 Wheel-Version: 1.0
 Generator: hatchling {__version__}
@@ -26,21 +27,19 @@ Root-Is-Purelib: true
 Tag: py2-none-any
 Tag: py3-none-any
 """,
-        )
-    )
-    files.append(
+        ),
         File(
-            Path(metadata_directory, 'METADATA'),
+            Path(metadata_directory, "METADATA"),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name']}
+Name: {kwargs["project_name"]}
 Version: 0.0.1
 License-File: LICENSE.txt
 """,
-        )
-    )
+        ),
+    ))
 
-    record_file = File(Path(metadata_directory, 'RECORD'), '')
+    record_file = File(Path(metadata_directory, "RECORD"), "")
     update_record_file_contents(record_file, files)
     files.append(record_file)
 
